PyXMake Developer Guide: PyXMake.Build.Make.Latex Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Attributes | List of all members
PyXMake.Build.Make.Latex Class Reference

Base class for all Latex build events. More...

Inheritance diagram for PyXMake.Build.Make.Latex:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| auth (self)
| Settings (cls, **kwargs)
| session (cls, *args, **kwargs)
| show (cls, ProjectID, *args, **kwargs)
| rename (cls, ProjectID, ProjectName, *args, **kwargs)
| upload (cls, archive, *args, **kwargs)
| download (cls, ProjectID, *args, **kwargs)
| delete (cls, ProjectID, *args, **kwargs)
| parse (cls, **kwargs)
| create (self, API="TeXworks", GUI=True, **kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
| __posix__ (self, **kwargs)
| AddIncludePath (self, includes)
| AddDependencyPath (self, dependencies)
| UseLibraries (self, libs)
| SourcePath (self, path)
| OutputPath (self, path, files="")
| Environment (self, path, script="ifortvars.bat")
| Preprocessing (self, cmdstring='', inend='', outend='', copyfiles=[], replace={'!DEC$ IF':'#IF','!DEC$ ELSE':'#ELSE','!DEC$ ENDIF':'#ENDIF'})
| Build (self, cmdstring, **kwargs)
| Postprocessing (self, cmdstring='')
| run (cls, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | MakeObjectKind = 'Latex'
| String identifier of current instance.
str | path2exe = ""
| Path to Latex executable.
str | exe = 'texify.exe'
| Executable of Latex.
| srcdir = os.path.dirname(os.path.abspath(self.srcs[0]))
| Set default source and output directories for Latex build objects.
| outdir = os.path.dirname(os.path.abspath(self.srcs[0]))
list | incdirs = []
| Blank version of list containing library directories without initially specifying MKL.
list | libdirs = []
| scrtdir
| buildid
| verbose
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid = BuildID
| Base string of build object.
list | srcs = []
| Source file or folders.
list | bare = not BuildID and not self.srcs
| stype = kwargs.get("stype",'Fortran')
| Source file type.
| verbose = verbose
| Level of verbosity of the current build object.
| hasFoss = kwargs.get("foss", Utility.GetExecutable("choco") or Utility.GetPlatform() in ["linux"] or kwargs.get("bash",False))
| Toggle between free open source software and commercial 3rd party libraries.
| scrtdir = os.getcwd()
| Current scratch directory
| srcdir = os.getcwd()
| Default search directory for source files.
| outdir = os.getcwd()
| Default search directory for output.
_, self.intelpath, self.iniCompiler | intelpath = content
| Path to Intel Fortran Compiler (read from Paths.log or empty).
tuple | temps = ()
| Tuple of data to be removed after job completion.
list | incdirs = []
| List of include directories.
list | libdirs = []
| List of library directories.
list | libs = []
| List of actual libraries (by name) used during linking.
list | copyfiles = []
| List of files to be copied to the output directory after finish.
str | iniCompiler = ""
| Default initialization of compiler script.
bool | setarch = True if kwargs.get('arch', None) in ['x86', 'x64'] else False
| Define the architecture for the build directly by using the keyword argument "arch".
| msvsc = kwargs.get("msvsc",'vs2015')
| Default version of Microsoft visual studio used by the Intel Fortran Compiler.
str | architecture = 'x86'
| Processor architecture.
str | postcmd = ""
| Post build command.
| buildname = self.temps + (inputfile, )
str | precmd = self.iniCompiler+" "+cmdstring
| Command executed during pre-build event.
| compargs = cmdstring
| Command line arguments passed in by the user.
str | makecmd = self.iniCompiler+" "+os.path.join(self.path2exe,self.exe)+" "+ cmd + cmdstring
| Command executed during build event.
| mkl_dependency

## Static Public Attributes
| base_url = os.getenv("pyx_overleaf_url","https://overleaf.fa-services.intra.dlr.de")
str | secret = "pyc_overleaf_secret" if os.getenv("pyc_overleaf_secret","") else "pyx_overleaf_secret"
| auth
| new = Utility.AbstractMethod(__new.__func__)

## Protected Attributes
dict | _auth = {} ;
Protected Attributes inherited from PyXMake.Build.Make.Make
list | _mkl_includes = [x for x in self.incdirs if "mkl" in x]

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Build.Make.Make
| __parser__ ()
| Detach ()
| F2CPreprocessing (PreprocessingFile)
| sanitize (string, **kwargs)
| setup (*args, **kwargs)
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Base class for all Latex build events.

    Inherited class to automatically build a documentation using Latex

Inherited from Make.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.Latex.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of Latex class object.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 3071 of file Make.py.

## Member Function Documentation

## ◆ auth()

PyXMake.Build.Make.Latex.auth | ( |  | self | ) |

    API access token defined as a protected class property for backwards compatibility.
    Works for both Python 2 and 3. Only meaningful when a remote Latex instance shall be called.

Definition at line 3122 of file Make.py.

## ◆ create()

PyXMake.Build.Make.Latex.create | ( |  | self,
|  |  | API = "TeXworks",
|  |  | GUI = True,
|  | ** | kwargs )

    Compile an existing project and/or start the graphical user interface.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 3382 of file Make.py.

## ◆ delete()

PyXMake.Build.Make.Latex.delete | ( |  | cls,
|  |  | ProjectID,
|  | * | args,
|  | ** | kwargs )

    Delete an Overleaf project given its ID.

Definition at line 3293 of file Make.py.

## ◆ download()

PyXMake.Build.Make.Latex.download | ( |  | cls,
|  |  | ProjectID,
|  | * | args,
|  | ** | kwargs )

    Download the complete archive or final pdf from an Overleaf project given its ID.

Definition at line 3260 of file Make.py.

## ◆ parse()

PyXMake.Build.Make.Latex.parse | ( |  | cls,
|  | ** | kwargs )

    Execute the current class as a CLI command.

Definition at line 3313 of file Make.py.

## ◆ rename()

PyXMake.Build.Make.Latex.rename | ( |  | cls,
|  |  | ProjectID,
|  |  | ProjectName,
|  | * | args,
|  | ** | kwargs )

    Rename an Overleaf project remotely given its ID.

Definition at line 3206 of file Make.py.

## ◆ session()

PyXMake.Build.Make.Latex.session | ( |  | cls,
|  | * | args,
|  | ** | kwargs )

    Create all required session tokens for an active Overleaf instance.

Definition at line 3145 of file Make.py.

## ◆ Settings()

PyXMake.Build.Make.Latex.Settings | ( |  | cls,
|  | ** | kwargs )

    Define environment variables for the default configuration file.

Definition at line 3136 of file Make.py.

## ◆ show()

PyXMake.Build.Make.Latex.show | ( |  | cls,
|  |  | ProjectID,
|  | * | args,
|  | ** | kwargs )

    Show all build files from an Overleaf project remotely given its ID.

    @note: Rebuilds the project in the process.

Definition at line 3183 of file Make.py.

## ◆ upload()

PyXMake.Build.Make.Latex.upload | ( |  | cls,
|  |  | archive,
|  | * | args,
|  | ** | kwargs )

    Upload a given archive to an active Overleaf instance creating a new project.

Definition at line 3227 of file Make.py.

## Member Data Documentation

## ◆ _auth

dict PyXMake.Build.Make.Latex._auth = {} ;
| protected

Definition at line 3129 of file Make.py.

## ◆ auth

PyXMake.Build.Make.Latex.auth
| static

Definition at line 3069 of file Make.py.

## ◆ base_url

PyXMake.Build.Make.Latex.base_url = os.getenv("pyx_overleaf_url","https://overleaf.fa-services.intra.dlr.de")
| static

Definition at line 3062 of file Make.py.

## ◆ buildid

PyXMake.Build.Make.Latex.buildid

Definition at line 3406 of file Make.py.

## ◆ exe

str PyXMake.Build.Make.Latex.exe = 'texify.exe'

Executable of Latex.

Definition at line 3105 of file Make.py.

## ◆ incdirs

list PyXMake.Build.Make.Latex.incdirs = []

Blank version of list containing library directories without initially specifying MKL.

Definition at line 3118 of file Make.py.

## ◆ libdirs

list PyXMake.Build.Make.Latex.libdirs = []

Definition at line 3119 of file Make.py.

## ◆ MakeObjectKind

str PyXMake.Build.Make.Latex.MakeObjectKind = 'Latex'

String identifier of current instance.

Definition at line 3080 of file Make.py.

## ◆ new

PyXMake.Build.Make.Latex.new = Utility.AbstractMethod(__new.__func__)
| static

Definition at line 3473 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.Latex.outdir = os.path.dirname(os.path.abspath(self.srcs[0]))

Definition at line 3111 of file Make.py.

## ◆ path2exe

str PyXMake.Build.Make.Latex.path2exe = ""

Path to Latex executable.

Set using environment variable

Definition at line 3103 of file Make.py.

## ◆ scrtdir

PyXMake.Build.Make.Latex.scrtdir

Definition at line 3395 of file Make.py.

## ◆ secret

PyXMake.Build.Make.Latex.secret = "pyc_overleaf_secret" if os.getenv("pyc_overleaf_secret","") else "pyx_overleaf_secret"
| static

Definition at line 3065 of file Make.py.

## ◆ srcdir

PyXMake.Build.Make.Latex.srcdir = os.path.dirname(os.path.abspath(self.srcs[0]))

Set default source and output directories for Latex build objects.

By default, both are set to the same folder containing the main source file.

Definition at line 3110 of file Make.py.

## ◆ verbose

PyXMake.Build.Make.Latex.verbose

Definition at line 3433 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py